import os
import mario
mario.activate(basedir=os.path.dirname(__file__))
from mario.origin import ProjectModule  # @UnresolvedImport


class ProjectModule(ProjectModule):

    # Attributes

    author = 'roll'
    author_email = 'roll@respect31.com'
    copyright = 'Copyright (c) 2014 Respect31 <post@respect31.com>'
    description = 'Mario is a framework to develop projects.'
    development_requires = ['packgram>=0.25']
    entry_points = {'console_scripts': ['mario = mario:program']}
    github_user = 'respect31'
    install_requires = [
        'sugarbowl', 'clyde', 'runfile', 'run-render', 'run-io']
    interpreters = ['3.3', '3.4']
    license = 'MIT License'
    name = 'mario'
    platforms = ['Unix']
    pypi_password_secure = 'cgrT/GvdW44j7BzM+CLDeBQpbAQwFOwmRs76c6o0o/QsaI2MvIRvkj5ij9QfKTdRfAqae3S2Anp6ZzfrYVvR+G37VJ8uplC1Y08Jo0xXA95f/nPtcNkLjktmDMjmz2gWxRK+ouDHxXVUkZ/YhuLDfz4svnbCay1/BYTLNgDAYuw='
    test_suite = 'nose.collector'
    version = '0.27.0'
